@@ -1,6 +1,6 @@
 package Agent::TCLI::Package::Net::Traceroute;
 #
-# $Id: Traceroute.pm 63 2007-05-03 15:57:38Z hacker $
+# $Id: Traceroute.pm 72 2007-06-07 11:05:52Z hacker $
 #
 =pod
 
@@ -41,7 +41,7 @@ use Agent::TCLI::Command;
 use Agent::TCLI::Parameter;
 
 
-our $VERSION = '0.020.'.sprintf "%04d", (qw($Id: Traceroute.pm 63 2007-05-03 15:57:38Z hacker $))[2];
+our $VERSION = '0.020.'.sprintf "%04d", (qw($Id: Traceroute.pm 72 2007-06-07 11:05:52Z hacker $))[2];
 
 =head2 ATTRIBUTES
 
@@ -550,7 +550,7 @@ details.
 
 =head1 AUTHOR
 
-Eric Hacker	 E<lt>perl.mod at erichacker.comE<gt>
+Eric Hacker	 E<lt>hacker at cpan.orgE<gt>
 
 =head1 BUGS
 
